# Package for BIFROST calculations

## Author: Nicolai Amin

## Date-Version: 06/05-2025 - v1.0

A library with tools for data analysis and reduction of BIFROST simulation data and/or resolution functions.
